bvx-es
======

elasticsearch util singleton class.

```
pip install bvx-es
```

# Usage

.env sample.

```
ES_HOSTS='[
  {
    "host": "127.0.0.1",
    "port": 9200
  },
  {
    "host": "127.0.0.1",
    "port": 9200
  },
  {
    "host": "127.0.0.1",
    "port": 9200
  }
]'
```

## Licence

[MIT](https://github.com/kotsutsumi/bvx-es/blob/main/LICENSE)

## Author

[kotsutsumi](https://github.com/kotsutsumi)
